
This is a **datetime widget** for for `YAFOWIL 
<http://pypi.python.org/pypi/yafowil>`_ - Yet Another Form WIdget Library.

It utilizes/integrates `jquery.ui.datepicker 
<http://docs.jquery.com/UI/Datepicker>`_ for/in YAFOWIL providing a 
datepicker function on a text input.

Contributors
============

- Robert Niederrreiter <rnix@squarewave.at>
